@@ -14,8 +14,6 @@ def download_model(model_name=None):
     if not (model_dir / model_name).exists():
 
         try:
-            (model_dir / model_name).mkdir(parents=True)
-
             url = 'https://www.pyspeech.com/static/model/recognition/allosaurus/' + model_name + '.tar.gz'
             print("downloading model ", model_name)
             print("from: ", url)
@@ -27,14 +25,14 @@ def download_model(model_name=None):
             files.extractall(str(model_dir))
 
         except:
-            print("could not download the model")
+            print("Error: could not download the model")
             (model_dir / model_name).rmdir()
 
 
 if __name__ == '__main__':
 
     parser = argparse.ArgumentParser('a utility to download pretrained models')
-    parser.add_argument('-m', '--model', default='latest',  help='specify which model to download. A list of downloadable files are available on Github')
+    parser.add_argument('-m', '--model', default='latest',  help='specify which model to download. A list of downloadable models are available on Github')
 
     args = parser.parse_args()
 
