@@ -2,9 +2,9 @@ from allosaurus.lm.decoder import PhoneDecoder
 import json
 from argparse import Namespace
 
-def read_lm(model_path):
+def read_lm(model_path, inference_config):
     """
-    simple factor method for feature model
+    read language model (phone inventory)
 
     :param pm_config:
     :return:
