@@ -21,7 +21,7 @@ class Inventory:
 
             lang_name = lang['LanguageName']
             phone_text = lang['phonelists']
-            self.lang_names.append(lang_name)
+            self.lang_names.append(lang_name.lower())
 
             self.lang2phonefile[lang_name.lower()] = phone_text
 
