@@ -8,8 +8,8 @@ if __name__ == '__main__':
     parser = argparse.ArgumentParser('Allosaurus phone recognizer')
     parser.add_argument('-d', '--device_id', type=int, default=-1, help='specify cuda device id to use, -1 means no cuda and will use cpu for inference')
     parser.add_argument('-m', '--model', type=str, default='latest', help='specify which model to use. default is to use the latest local model')
-    parser.add_argument('-l', '--lang', type=str, default='ipa',help='specify which language inventory to use for recognition. default is to use all phone inventory')
-    parser.add_argument('-i', '--input', type=str, help='specify your input wav file')
+    parser.add_argument('-l', '--lang', type=str,  default='ipa',help='specify which language inventory to use for recognition. default is to use all phone inventory')
+    parser.add_argument('-i', '--input', type=str, required=True, help='specify your input wav file')
 
     args = parser.parse_args()
 
